Index: src/interpreter/interpreter.cc |
diff --git a/src/interpreter/interpreter.cc b/src/interpreter/interpreter.cc |
index 19151963540096f17b4fcddd5d727599b15a85df..3099fdfc76630ac37b5fc6c56b3f51483cb05773 100644 |
--- a/src/interpreter/interpreter.cc |
+++ b/src/interpreter/interpreter.cc |
@@ -1369,31 +1369,20 @@ |
} |
// CreateClosure <index> <tenured> |
// |
// Creates a new closure for SharedFunctionInfo at position |index| in the |
// constant pool and with the PretenureFlag <tenured>. |
void Interpreter::DoCreateClosure(compiler::InterpreterAssembler* assembler) { |
// TODO(rmcilroy): Possibly call FastNewClosureStub when possible instead of |
// calling into the runtime. |
- Node* index = __ BytecodeOperandIdx(0); |
- Node* shared = __ LoadConstantPoolEntry(index); |
- Node* tenured_raw = __ BytecodeOperandImm(1); |
+ Node* shared = __ GetAccumulator(); |
+ Node* tenured_raw = __ BytecodeOperandImm(0); |
Node* tenured = __ SmiTag(tenured_raw); |
Node* result = |
__ CallRuntime(Runtime::kInterpreterNewClosure, shared, tenured); |
__ SetAccumulator(result); |
__ Dispatch(); |
-} |
- |
- |
-// CreateClosureWide <index> <tenured> |
-// |
-// Creates a new closure for SharedFunctionInfo at position |index| in the |
-// constant pool and with the PretenureFlag <tenured>. |
-void Interpreter::DoCreateClosureWide( |
- compiler::InterpreterAssembler* assembler) { |
- return DoCreateClosure(assembler); |
} |
@@ -1369,31 +1369,20 @@ |
} |
-// CreateClosure <index> <tenured> |
-// |
-// Creates a new closure for SharedFunctionInfo at position |index| in the |
-// constant pool and with the PretenureFlag <tenured>. |
+// CreateClosure <tenured> |
+// |
+// Creates a new closure for SharedFunctionInfo in the accumulator with the |
+// PretenureFlag <tenured>. |
void Interpreter::DoCreateClosure(compiler::InterpreterAssembler* assembler) { |
// TODO(rmcilroy): Possibly call FastNewClosureStub when possible instead of |